@@ -7,8 +7,7 @@
 #pragma once
 
 #include "VideoPlatform.h"
-#include <PipeWireRecord>
-#include <QFuture>
+#include <KPipeWire/PipeWireRecord>
 #include <memory>
 
 class Screencasting;
@@ -25,24 +24,11 @@ public:
     VideoPlatformWayland(QObject *parent = nullptr);
 
     RecordingModes supportedRecordingModes() const override;
-    Formats supportedFormats() const override;
-    void startRecording(const QUrl &fileUrl, RecordingMode recordingMode, const QVariantMap &options, bool includePointer) override;
+    void startRecording(const QString &path, RecordingMode recordingMode, const RecordingOption &option, bool includePointer) override;
     void finishRecording() override;
-
-    Format formatForEncoder(PipeWireBaseEncodedStream::Encoder encoder) const;
-    PipeWireBaseEncodedStream::Encoder encoderForFormat(Format format) const;
-
-protected:
-    void timerEvent(QTimerEvent *event) override;
+    QString extension() const override;
 
 private:
-    void initialize();
-    bool mkDirPath(const QUrl &fileUrl);
-    void selectAndRecord(const QUrl &fileUrl, RecordingMode recordingMode, bool includePointer);
-
     Screencasting *const m_screencasting;
     std::unique_ptr<PipeWireRecord> m_recorder;
-    QFuture<void> m_recorderFuture;
-    int m_frameBytes;
-    QBasicTimer m_memoryTimer;
 };
